@@ -1,4 +1,4 @@
-{% load url from future %}/**
+/**
  * Based on "TinyMCE Compressor PHP v2.0.4" from MoxieCode.
  *
  * http://tinymce.moxiecode.com/
@@ -134,7 +134,11 @@ var tinyMCE_GZ = {
 		se.text = co;
 
 		// Add it to evaluate it and remove it
-		(document.getElementsByTagName('head')[0] || document.documentElement).appendChild(se);
+		try {
+		  (document.getElementsByTagName('head')[0] || document.documentElement).appendChild(se);
+		} catch (error) {
+		  console.error(error, "Tried to eval:", se);
+		}
 		se.parentNode.removeChild(se);
 	}
 };
