@@ -7,29 +7,26 @@ http://code.djangoproject.com/wiki/CustomWidgetsTinyMCE
 """
 from collections import OrderedDict
 import json
+from pathlib import Path
+import warnings
 
 from django import forms
 from django.conf import settings
 from django.contrib.admin import widgets as admin_widgets
 from django.forms.utils import flatatt
+from django.urls import reverse
 from django.utils.encoding import force_text
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
-from django.utils.translation import get_language, ugettext as _
+from django.utils.translation import get_language, gettext as _, to_locale
 
 import tinymce.settings
 
-try:
-    from django.urls import reverse
-except ImportError:
-    # Django < 1.10
-    from django.core.urlresolvers import reverse
-
 
 class TinyMCE(forms.Textarea):
     """
     TinyMCE widget. Set settings.TINYMCE_JS_URL to set the location of the
-    javascript file. Default is "MEDIA_URL + 'js/tiny_mce/tiny_mce.js'".
+    javascript file. Default is "STATIC_URL + 'tinymce/tinymce.min.js'".
     You can customize the configuration with the mce_attrs argument to the
     constructor.
 
@@ -45,14 +42,12 @@ class TinyMCE(forms.Textarea):
     """
 
     def __init__(self, content_language=None, attrs=None, mce_attrs=None):
-        super(TinyMCE, self).__init__(attrs)
+        super().__init__(attrs)
         mce_attrs = mce_attrs or {}
         self.mce_attrs = mce_attrs
         if "mode" not in self.mce_attrs:
             self.mce_attrs["mode"] = "exact"
         self.mce_attrs["strict_loading_mode"] = 1
-        if content_language is None:
-            content_language = mce_attrs.get("language", None)
         self.content_language = content_language
 
     def use_required_attribute(self, *args):
@@ -61,7 +56,10 @@ class TinyMCE(forms.Textarea):
 
     def get_mce_config(self, attrs):
         mce_config = tinymce.settings.DEFAULT_CONFIG.copy()
-        mce_config.update(get_language_config(self.content_language))
+        if "language" not in mce_config:
+            mce_config["language"] = get_language_from_django()
+        mce_config["language"] = match_language_with_tinymce(mce_config["language"])
+        mce_config.update(get_language_config(self.content_language or mce_config["language"]))
         if tinymce.settings.USE_FILEBROWSER:
             mce_config["file_browser_callback"] = "djangoFileBrowser"
         mce_config.update(self.mce_attrs)
@@ -109,8 +107,6 @@ class TinyMCE(forms.Textarea):
 
             if "css" in tinymce.settings.USE_EXTRA_MEDIA:
                 css = tinymce.settings.USE_EXTRA_MEDIA["css"]
-        if tinymce.settings.INCLUDE_JQUERY:
-            js.append("django_tinymce/jquery-1.9.1.min.js")
         js.append("django_tinymce/init_tinymce.js")
         return forms.Media(css=css, js=js)
 
@@ -121,17 +117,38 @@ class AdminTinyMCE(TinyMCE, admin_widgets.AdminTextareaWidget):
     pass
 
 
-def get_language_config(content_language=None):
+def get_language_from_django():
     language = get_language()
-    language = language[:2] if language is not None else "en"
-    if content_language:
-        content_language = content_language[:2]
-    else:
-        content_language = language
+    language = to_locale(language) if language is not None else "en_US"
+    return language
+
+
+def match_language_with_tinymce(lang):
+    """
+    Language codes in TinyMCE are inconsistent. E.g. Hebrew is he_IL.js, while
+    Danish is da.js. So we apply some heuristic to find a language code
+    with an existing TinyMCE translation file.
+    """
+    if lang.startswith("en"):
+        return lang
+    # Read tinymce langs from tinymce/static/tinymce/langs/
+    tiny_lang_dir = Path(__file__).parent / "static" / "tinymce" / "langs"
+    tiny_langs = [file_.stem for file_ in tiny_lang_dir.iterdir() if file_.suffix == ".js"]
+    if lang in tiny_langs:
+        return lang
+    if lang[:2] in tiny_langs:
+        return lang[:2]
+    two_letter_map = {lg[:2]: lg for lg in tiny_langs}
+    if lang[:2] in two_letter_map:
+        return two_letter_map[lang[:2]]
+    warnings.warn(f"No TinyMCE language found for '{lang}', defaulting to 'en_US'", RuntimeWarning)
+    return "en_US"
+
+
+def get_language_config(content_language):
+    content_language = content_language[:2]
 
     config = {}
-    config["language"] = language
-
     lang_names = OrderedDict()
     for lang, name in settings.LANGUAGES:
         if lang[:2] not in lang_names:
